@@ -10,7 +10,7 @@ from __future__ import absolute_import
 
 import sys
 
-__all__ = ["detect_environment"]
+__all__ = ['detect_environment']
 
 _environment = None
 
@@ -25,28 +25,28 @@ def select_blocking_method(type):
 
 def _detect_environment():
     ## -eventlet-
-    if "eventlet" in sys.modules:
+    if 'eventlet' in sys.modules:
         try:
             from eventlet.patcher import is_monkey_patched as is_eventlet
             import socket
 
             if is_eventlet(socket):
-                return "eventlet"
+                return 'eventlet'
         except ImportError:
             pass
 
     # -gevent-
-    if "gevent" in sys.modules:
+    if 'gevent' in sys.modules:
         try:
             from gevent import socket as _gsocket
             import socket
 
             if socket.socket is _gsocket.socket:
-                return "gevent"
+                return 'gevent'
         except ImportError:
             pass
 
-    return "default"
+    return 'default'
 
 
 def detect_environment():
